@@ -113,6 +113,32 @@ class te_services:
         })
         return projectData
 
+    def getPerformanceProjectData(self, tableName, count=1, consumed=True,
+                                  queryJSON=None, projectName=None, isE2E=False):
+        _projectName = projectName if projectName is not None else self.te_config_json[
+            "Project"]
+        requestUR = self.te_config_json["Server"]+ "/" + \
+            self.te_constant["ServerAPI"]["PROJECT_DATA"] + \
+            "/" + _projectName + \
+            "/" + tableName + \
+            "/performance/" + str(count) + \
+            "/" + str(consumed)
+        if isE2E:
+            if queryJSON is None:
+                queryJSON = {}
+            queryJSON["_buildid"] = self.te_config_json["BuildID"]
+        if queryJSON is not None:
+            qString = urlencode(queryJSON)
+            requestUR += "?"+qString
+        result = requests.get(requestUR, headers=self.headers)
+        projectData = json.loads(result.text)
+        self.addE2EData({
+            "name": self.te_constant["E2EDataType"].get("INTPUT"),
+            "type": self.te_constant["E2ETableType"].get("PROJECT"),
+            "description": projectData
+        })
+        return projectData
+
     def getMasterData(self, tableName, queryJSON=None, projectName=None, isE2E=False):
         _projectName = projectName if projectName is not None else self.te_config_json[
             "Project"]
@@ -136,6 +162,32 @@ class te_services:
         })
         return masterData
 
+    def getPerformanceMasterData(self, tableName, count=1, consumed=True,
+                                 queryJSON=None, projectName=None, isE2E=False):
+        _projectName = projectName if projectName is not None else self.te_config_json[
+            "Project"]
+        requestUR = self.te_config_json["Server"]+"/" + \
+            self.te_constant["ServerAPI"]["MASTER_DATA"] + \
+            "/" + _projectName + \
+            "/" + tableName + \
+            "/performance/" + str(count) + \
+            "/" + str(consumed)
+        if isE2E:
+            if queryJSON is None:
+                queryJSON = {}
+            queryJSON["_buildid"] = self.te_config_json["BuildID"]
+        if queryJSON is not None:
+            qString = urlencode(queryJSON)
+            requestUR += "?"+qString
+        result = requests.get(requestUR, headers=self.headers)
+        masterData = json.loads(result.text)
+        self.addE2EData({
+            "name": self.te_constant["E2EDataType"].get("INTPUT"),
+            "type": self.te_constant["E2ETableType"].get("MASTER"),
+            "description": masterData
+        })
+        return masterData
+
     def getCaseData(self, caseName, projectName=None):
         _projectName = projectName if projectName is not None else self.te_config_json[
             "Project"]
@@ -227,6 +279,40 @@ class te_services:
         caseData = json.loads(result.text)
         return caseData
 
+    def deleteProjectData(self, tableName, id, projectName=None):
+        _projectName = projectName if projectName is not None else self.te_config_json[
+            "Project"]
+        requestUR = self.te_config_json["Server"]+"/" + \
+            self.te_constant["ServerAPI"]["PROJECT_DATA"] + \
+            "/" + _projectName + \
+            "/" + tableName + \
+            "/" + id
+        result = requests.delete(requestUR,  headers=self.headers)
+        projectData = json.loads(result.text)
+        self.addE2EData({
+            "name": self.te_constant["E2EDataType"].get("OUTPUT"),
+            "type": self.te_constant["E2ETableType"].get("PROJECT"),
+            "description": projectData
+        })
+        return projectData
+
+    def deleteMasterData(self, tableName, id, projectName=None):
+        _projectName = projectName if projectName is not None else self.te_config_json[
+            "Project"]
+        requestUR = self.te_config_json["Server"]+"/" + \
+            self.te_constant["ServerAPI"]["MASTER_DATA"] + \
+            "/" + _projectName + \
+            "/" + tableName + \
+            "/" + id
+        result = requests.delete(requestUR,  headers=self.headers)
+        masterData = json.loads(result.text)
+        self.addE2EData({
+            "name": self.te_constant["E2EDataType"].get("OUTPUT"),
+            "type": self.te_constant["E2ETableType"].get("MASTER"),
+            "description": masterData
+        })
+        return masterData
+
     def uploadJSONReport(self, projectName=None):
         # get report
         reportPath = os.path.join(self.te_config_json.get("Report").get(
